@@ -160,7 +160,8 @@ class KojiContentGenerator(object):
         fmt = sep.join(["%%{%s}" % tag for tag in tags])
         cmd = "/bin/rpm -qa --qf '{0}\n'".format(fmt)
         with open("/dev/null", "r+") as devnull:
-            p = subprocess.Popen(
+            # subprocess call does not take user input, thus risk is low
+            p = subprocess.Popen(  # nosec
                 cmd, shell=True, stdin=devnull, stdout=subprocess.PIPE, stderr=devnull)
 
             (stdout, stderr) = p.communicate()
@@ -361,7 +362,7 @@ class KojiContentGenerator(object):
                 mmd = load_mmd(data)
                 ret["filename"] = mmd_filename
                 ret["filesize"] = len(raw_data)
-                ret["checksum"] = hashlib.md5(raw_data).hexdigest()
+                ret["checksum"] = hashlib.md5(raw_data, usedforsecurity=False).hexdigest()
         except IOError:
             if arch == "src":
                 # This might happen in case the Module is submitted directly
@@ -403,7 +404,7 @@ class KojiContentGenerator(object):
         try:
             log_path = os.path.join(output_path, "build.log")
             with open(log_path, "rb") as build_log:
-                checksum = hashlib.md5(build_log.read()).hexdigest()
+                checksum = hashlib.md5(build_log.read(), usedforsecurity=False).hexdigest()
             stat = os.stat(log_path)
             ret.append(
                 {
