@@ -228,10 +228,10 @@ def import_builds_from_local_dnf_repos(platform_id=None):
     if not platform_id:
         # Parse the /etc/os-release to find out the local platform:stream.
         with open("/etc/os-release", "r") as fd:
-            for l in fd.readlines():
-                if not l.startswith("PLATFORM_ID"):
+            for line in fd.readlines():
+                if not line.startswith("PLATFORM_ID"):
                     continue
-                platform_id = l.split("=")[1].strip("\"' \n")
+                platform_id = line.split("=")[1].strip("\"' \n")
     if not platform_id:
         raise ValueError("Cannot get PLATFORM_ID from /etc/os-release.")
 
@@ -413,8 +413,8 @@ class MockModuleBuilder(GenericBuilder):
         # ...and inject modules.yaml there if asked.
         if include_module_yaml:
             mmd_path = os.path.join(path, "modules.yaml")
-            with open(mmd_path, "w") as f:
-                f.write(mmd_to_str(m1_mmd))
+            with open(mmd_path, "wb") as f:
+                f.write(mmd_to_str(m1_mmd).encode("utf-8"))
             execute_cmd(["/usr/bin/modifyrepo_c", "--mdtype=modules", mmd_path, repodata_path])
 
     def _add_repo(self, name, baseurl, extra=""):
@@ -459,7 +459,9 @@ class MockModuleBuilder(GenericBuilder):
                 config_opts = {}
                 code = compile(f.read(), infile, "exec")
                 # pylint: disable=exec-used
-                exec(code)
+                # exec is not being called with user input
+                # only used for local builds, never on the server
+                exec(code)  # nosec
 
                 self.groups = config_opts["chroot_setup_cmd"].split(" ")[1:]
                 self.yum_conf = config_opts["yum.conf"]
@@ -536,7 +538,7 @@ class MockModuleBuilder(GenericBuilder):
             # If source starts with mock_resultdir, it means it is path to local
             # module build repository.
             if source.startswith(conf.mock_resultsdir):
-                repo_name = os.path.basename(source)
+                repo_name = os.path.basename(os.path.dirname(source))
                 if repo_name.startswith("module-"):
                     repo_name = repo_name[7:]
                 repo_dir = source
@@ -618,13 +620,6 @@ class MockModuleBuilder(GenericBuilder):
             if os.path.isfile(log_path) and os.path.getsize(log_path) == 0:
                 os.remove(log_path)
 
-            # Remove other files containing useless information
-            elif logf.endswith("-srpm-stdout.log"):
-                with open(log_path) as f:
-                    data = f.read(4096)
-                    if re.match("Downloading [^\n]*\n\n\nWrote: [^\n]", data):
-                        os.remove(log_path)
-
     def build_srpm(self, artifact_name, source, build_id, builder):
         """
         Builds the artifact from the SRPM.
@@ -779,6 +774,26 @@ class MockModuleBuilder(GenericBuilder):
             nvrs = set(kobo.rpmlib.make_nvr(rpm, force_epoch=True) for rpm in rpms)
             return list(nvrs)
 
+    def get_average_build_time(self, component):
+        """
+        Get the average build time of the component from Koji
+        :param component: a ComponentBuild object
+        :return: a float of the average build time in seconds
+        """
+        # We currently don't track build times in MBS directly, so we can use Koji to get a decent
+        # estimate
+        if not self.koji_session:
+            # If Koji is not configured on the system, then just return 0.0 for components
+            try:
+                self.koji_session = get_session(self.config, login=False)
+                # If the component has not been built before, then None is returned. Instead,
+                # let's return 0.0 so the type is consistent
+                return self.koji_session.getAverageBuildDuration(component.package) or 0.0
+            except Exception:
+                log.debug(
+                    "The Koji call to getAverageBuildDuration failed. Is Koji properly configured?")
+                return 0.0
+
 
 class BaseBuilder(object):
     def __init__(self, config, resultsdir):
@@ -836,33 +851,8 @@ class SCMBuilder(BaseBuilder):
                 src_dir = repo_path[len("file://"):]
                 f.write("config_opts['scm_opts']['ext_src_dir'] = '{}'\n".format(src_dir))
 
-    def _make_executable(self, path):
-        mode = os.stat(path).st_mode
-        mode |= (mode & 0o444) >> 2  # copy R bits to X
-        os.chmod(path, mode)
-
     def _get_distgit_commands(self, source):
         for host, cmds in conf.distgits.items():
             if source.startswith(host):
                 return cmds
         raise KeyError("No defined commands for {}".format(source))
-
-    def get_average_build_time(self, component):
-        """
-        Get the average build time of the component from Koji
-        :param component: a ComponentBuild object
-        :return: a float of the average build time in seconds
-        """
-        # We currently don't track build times in MBS directly, so we can use Koji to get a decent
-        # estimate
-        if not self.koji_session:
-            # If Koji is not configured on the system, then just return 0.0 for components
-            try:
-                self.koji_session = get_session(self.config, login=False)
-                # If the component has not been built before, then None is returned. Instead,
-                # let's return 0.0 so the type is consistent
-                return self.koji_session.getAverageBuildDuration(component.package) or 0.0
-            except Exception:
-                log.debug(
-                    "The Koji call to getAverageBuildDuration failed. Is Koji properly configured?")
-                return 0.0
