@@ -89,7 +89,7 @@ def create_local_repo_from_koji_tag(config, tag, repo_dir, archs=None):
     # Load koji config and create Koji session.
     koji_config = get_koji_config(config)
     address = koji_config.server
-    log.info("Connecting to koji %r" % address)
+    log.debug("Connecting to koji %r" % address)
     session = koji.ClientSession(address, opts=koji_config)
 
     # Get the list of all RPMs and builds in a tag.
@@ -190,7 +190,7 @@ def get_rpm_release(db_session, module_build):
         str(module_build.version),
         str(module_build.context),
     ]).encode("utf-8")
-    dist_hash = hashlib.sha1(dist_str).hexdigest()[:8]
+    dist_hash = hashlib.sha1(dist_str, usedforsecurity=False).hexdigest()[:8]
 
     # We need to share the same auto-incrementing index in dist tag between all MSE builds.
     # We can achieve that by using the lowest build ID of all the MSE siblings including
