@@ -35,12 +35,14 @@ class BaseConfiguration(object):
         os.getcwd(), "module_build_service.db"))
     SQLALCHEMY_TRACK_MODIFICATIONS = True
     # Where we should run when running "manage.py run" directly.
-    HOST = "0.0.0.0"
+    HOST = None  # Flask will default to 127.0.0.1
     PORT = 5000
 
 
 class TestConfiguration(BaseConfiguration):
     LOG_LEVEL = "debug"
+    # This is just for initialization - we override this with a database in the
+    # pytest temporary directory
     SQLALCHEMY_DATABASE_URI = os.environ.get("DATABASE_URI", "sqlite:///:memory:")
     DEBUG = True
     MESSAGING = "in_memory"
@@ -62,11 +64,6 @@ class TestConfiguration(BaseConfiguration):
 
     ALLOWED_GROUPS_TO_IMPORT_MODULE = {"mbs-import-module"}
 
-    # Greenwave configuration
-    GREENWAVE_URL = "https://greenwave.example.local/api/v1.0/"
-    GREENWAVE_DECISION_CONTEXT = "test_dec_context"
-    GREENWAVE_SUBJECT_TYPE = "some-module"
-
     STREAM_SUFFIXES = {r"^el\d+\.\d+\.\d+\.z$": 0.1}
 
     # Ensures task.delay executes locally instead of scheduling a task to a queue.
@@ -80,13 +77,16 @@ class ProdConfiguration(BaseConfiguration):
 class LocalBuildConfiguration(BaseConfiguration):
     CACHE_DIR = "~/modulebuild/cache"
     LOG_LEVEL = "debug"
-    MESSAGING = "in_memory"
+    MESSAGING = "drop"
 
     ALLOW_CUSTOM_SCMURLS = True
     RESOLVER = "mbs"
     RPMS_ALLOW_REPOSITORY = True
     MODULES_ALLOW_REPOSITORY = True
 
+    # Match the Fedora server-side configuration
+    ALLOW_ONLY_COMPATIBLE_BASE_MODULES = False
+
     # Celery tasks will be executed locally for local builds
     CELERY_TASK_ALWAYS_EAGER = True
 
@@ -445,8 +445,18 @@ class Config(object):
             "type": bool,
             "default": True,
             "desc": "When True, only modules built on top of compatible base modules are "
-                    "considered by MBS as possible buildrequirement. When False, modules "
-                    "built against any base module stream can be used as a buildrequire.",
+                    "considered by MBS as possible buildrequirement or as a reuse candidate. "
+                    "When False, modules built against any base module stream sharing a "
+                    "virtual stream can be used as a buildrequire, but only modules built "
+                    "against the exact same base module stream are considered as candidates "
+                    "for reuse. Setting this to True requires base module streams to be of the "
+                    " form: <prefix><x>.<y>.<z>.",
+        },
+        "base_module_stream_exclusions": {
+            "type": list,
+            "default": [],
+            "desc":
+                "List of base module streams to exclude from stream expansion"
         },
         "koji_cg_tag_build": {
             "type": bool,
@@ -599,11 +609,6 @@ class Config(object):
             ],
             "desc": ("The list packages for offline module build RPM buildroot."),
         },
-        "greenwave_decision_context": {
-            "type": str,
-            "default": "",
-            "desc": "The Greenwave decision context that determines a module's gating status.",
-        },
         "allowed_privileged_module_names": {
             "type": list,
             "default": [],
@@ -622,22 +627,6 @@ class Config(object):
             "corresponding suffix added to formatted stream version. "
             'For example, {r"regexp": 0.1, ...}',
         },
-        "greenwave_url": {
-            "type": str,
-            "default": "",
-            "desc": "The URL of the server where Greenwave is running (should include "
-                    "the root of the API)"
-        },
-        "greenwave_subject_type": {
-            "type": str,
-            "default": "",
-            "desc": "Subject type for Greenwave requests"
-        },
-        "greenwave_timeout": {
-            "type": int,
-            "default": 60,
-            "desc": "Greenwave response timeout"
-        },
         "modules_allow_scratch": {
             "type": bool,
             "default": False,
@@ -671,8 +660,15 @@ class Config(object):
         "product_pages_schedule_task_name": {
             "type": str,
             "default": "",
-            "desc": "A schedule task name. This is used to check Product schedules for cases where "
-                    "the stream should be used before release."
+            "desc": "The name of the governing schedule task. The finish date from the matching"
+                    "task is used to determine if a stream suffix should be added ahead of the GA"
+                    "date. The comparison is case insensitive."
+        },
+        "product_pages_schedule_task_names": {
+            "type": list,
+            "default": [],
+            "desc": "Like product_pages_schedule_task_name, but accepts a list. The list is"
+                    "treated as order of preference."
         },
         "num_threads_for_build_submissions": {
             "type": int,
@@ -687,6 +683,11 @@ class Config(object):
                     "which buildrequires to automatically include. This can be overridden with "
                     "the xmd.mbs.default_modules_scm_url key in the base module's modulemd.",
         },
+        "default_branch": {
+            "type": str,
+            "default": "master",
+            "desc": "Denotes the default branch.",
+        },
         "uses_rawhide": {
             "type": bool,
             "default": True,
@@ -742,11 +743,20 @@ class Config(object):
                 "module_build_service.scheduler.handlers.modules",
                 "module_build_service.scheduler.handlers.repos",
                 "module_build_service.scheduler.handlers.tags",
-                "module_build_service.scheduler.handlers.greenwave",
                 "module_build_service.scheduler.producer",
             ],
             "desc": "The list Python paths for the Celery application to import.",
         },
+        "allow_dashes_in_svc": {
+            "type": bool,
+            "default": False,
+            "desc": "Whether to allow dashes in stream, version, and context values.",
+        },
+        "strict_module_state_transitions": {
+            "type": bool,
+            "default": True,
+            "desc": "Whether to strictly enforce module state transitions",
+        },
     }
 
     def __init__(self, conf_section_obj):
@@ -871,14 +881,14 @@ class Config(object):
             )
         self._messaging = s
 
-    def _setifok_amq_recv_addresses(self, l):
-        assert isinstance(l, list) or isinstance(l, tuple)
-        self._amq_recv_addresses = list(l)
+    def _setifok_amq_recv_addresses(self, values):
+        assert isinstance(values, list) or isinstance(values, tuple)
+        self._amq_recv_addresses = list(values)
 
-    def _setifok_scmurls(self, l):
-        if not isinstance(l, list):
+    def _setifok_scmurls(self, values):
+        if not isinstance(values, list):
             raise TypeError("scmurls needs to be a list.")
-        self._scmurls = [str(x) for x in l]
+        self._scmurls = [str(x) for x in values]
 
     def _setifok_num_concurrent_builds(self, i):
         if not isinstance(i, int):
