@@ -548,7 +548,7 @@ class ModuleBuild(MBSBase):
             if dep not in deps_to_filter
         }
         property_json = json.dumps(OrderedDict(sorted(mmd_formatted_buildrequires.items())))
-        return hashlib.sha1(property_json.encode("utf-8")).hexdigest()
+        return hashlib.sha1(property_json.encode("utf-8"), usedforsecurity=False).hexdigest()
 
     @staticmethod
     def calculate_runtime_context(mmd_dependencies):
@@ -567,7 +567,7 @@ class ModuleBuild(MBSBase):
         # Sort the streams for each module name and also sort the module names.
         mmd_requires = {dep: sorted(list(streams)) for dep, streams in mmd_requires.items()}
         property_json = json.dumps(OrderedDict(sorted(mmd_requires.items())))
-        return hashlib.sha1(property_json.encode("utf-8")).hexdigest()
+        return hashlib.sha1(property_json.encode("utf-8"), usedforsecurity=False).hexdigest()
 
     @staticmethod
     def calculate_module_context(build_context, runtime_context):
@@ -581,7 +581,7 @@ class ModuleBuild(MBSBase):
         :return: module context hash
         """
         combined_hashes = "{0}:{1}".format(build_context, runtime_context)
-        return hashlib.sha1(combined_hashes.encode("utf-8")).hexdigest()[:8]
+        return hashlib.sha1(combined_hashes.encode("utf-8"), usedforsecurity=False).hexdigest()[:8]
 
     def siblings(self, db_session):
         query = db_session.query(ModuleBuild).filter(
@@ -621,6 +621,7 @@ class ModuleBuild(MBSBase):
         rebuild_strategy=None,
         scratch=False,
         srpms=None,
+        commit=True,
         **kwargs
     ):
         now = datetime.utcnow()
@@ -650,7 +651,8 @@ class ModuleBuild(MBSBase):
             module.buildrequires.append(base_module)
 
         db_session.add(module)
-        db_session.commit()
+        if commit:
+            db_session.commit()
         return module
 
     def transition(self, db_session, conf, state, state_reason=None, failure_type="unspec"):
@@ -1105,6 +1107,10 @@ class ComponentBuild(MBSBase):
         Index("idx_component_builds_build_id_nvr", "module_id", "nvr", unique=True),
     )
 
+    @classmethod
+    def from_id(cls, db_session, component_build_id):
+        return db_session.query(cls).filter(cls.id == component_build_id).first()
+
     @classmethod
     def from_component_event(cls, db_session, task_id, module_id=None):
         _filter = db_session.query(cls).filter
