@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MIT
 from __future__ import absolute_import, print_function
+from collections import defaultdict
 from functools import wraps
 import getpass
 import logging
 import os
+import sys
 import textwrap
 
 import flask_migrate
@@ -16,7 +18,7 @@ from module_build_service.builder.MockModuleBuilder import (
     import_builds_from_local_dnf_repos, load_local_builds
 )
 from module_build_service.common import conf, models
-from module_build_service.common.errors import StreamAmbigous
+from module_build_service.common.errors import StreamAmbigous, StreamNotXyz
 from module_build_service.common.logger import level_flags
 from module_build_service.common.utils import load_mmd_file, import_mmd
 import module_build_service.scheduler.consumer
@@ -103,11 +105,33 @@ def import_module(mmd_file):
     import_mmd(db.session, mmd)
 
 
+def collect_dep_overrides(overrides):
+    collected = defaultdict(list)
+    for value in overrides:
+        parts = value.split(":")
+        if len(parts) != 2:
+            raise ValueError("dependency overrides must be in the form name:stream")
+        name, stream = parts
+        collected[name].append(stream)
+
+    return collected
+
+
 @manager.option("--stream", action="store", dest="stream")
 @manager.option("--file", action="store", dest="yaml_file")
 @manager.option("--srpm", action="append", default=[], dest="srpms", metavar="SRPM")
 @manager.option("--skiptests", action="store_true", dest="skiptests")
 @manager.option("--offline", action="store_true", dest="offline")
+@manager.option(
+    '--buildrequires', action='append', metavar='name:stream',
+    dest='buildrequires', default=[],
+    help='Buildrequires to override in the form of "name:stream"'
+)
+@manager.option(
+    '--requires', action='append', metavar='name:stream',
+    dest='requires', default=[],
+    help='Requires to override in the form of "name:stream"'
+)
 @manager.option("-d", "--debug", action="store_true", dest="log_debug")
 @manager.option("-l", "--add-local-build", action="append", default=None, dest="local_build_nsvs")
 @manager.option("-s", "--set-stream", action="append", default=[], dest="default_streams")
@@ -125,6 +149,8 @@ def build_module_locally(
     offline=False,
     platform_repofiles=None,
     platform_id=None,
+    requires=None,
+    buildrequires=None,
     log_debug=False,
 ):
     """ Performs local module build using Mock
@@ -163,7 +189,9 @@ def build_module_locally(
 
     params = {
         "local_build": True,
-        "default_streams": dict(ns.split(":") for ns in default_streams)
+        "default_streams": dict(ns.split(":") for ns in default_streams),
+        "require_overrides": collect_dep_overrides(requires),
+        "buildrequire_overrides": collect_dep_overrides(buildrequires),
     }
     if srpms:
         params["srpms"] = srpms
@@ -190,19 +218,19 @@ def build_module_locally(
         except StreamAmbigous as e:
             logging.error(str(e))
             logging.error("Use '-s module_name:module_stream' to choose the stream")
-            return
+            return 1
+        except StreamNotXyz as e:
+            logging.error(str(e))
+            logging.error("Use '--buildrequires name:stream' to override the base module stream")
+            return 1
 
         module_build_ids = [build.id for build in module_builds]
 
-    module_build_service.scheduler.local.main(module_build_ids)
-
-    has_failed_module = db_session.query(models.ModuleBuild).filter(
-        models.ModuleBuild.id.in_(module_build_ids),
-        models.ModuleBuild.state == models.BUILD_STATES["failed"],
-    ).count() > 0
-
-    if has_failed_module:
-        raise RuntimeError("Module build failed")
+    try:
+        module_build_service.scheduler.local.main(module_build_ids)
+    except module_build_service.scheduler.local.BuildFailed as e:
+        logging.error("%s", e)
+        sys.exit(1)
 
 
 @manager.option(
@@ -263,7 +291,7 @@ def retire(identifier, confirm=False):
 @console_script_help
 @manager.command
 def run(host=None, port=None, debug=None):
-    """ Runs the Flask app, locally.
+    """ Runs the Flask app, locally. Intended for dev instances, should not be used for production.
     """
     host = host or conf.host
     port = port or conf.port
