@@ -60,7 +60,7 @@ def upgrade():
             mmd_formatted_property = {
                 dep: info['ref'] for dep, info in mbs_xmd[xmd_name].items()}
             property_json = json.dumps(OrderedDict(sorted(mmd_formatted_property.items())))
-            contexts[xmd_name] = hashlib.sha1(property_json).hexdigest()
+            contexts[xmd_name] = hashlib.sha1(property_json, usedforsecurity=False).hexdigest()
 
         # Update the database now
         if len(contexts) == 2:
