@@ -62,7 +62,7 @@ def upgrade():
         mmd_formatted_buildrequires = {
             dep: info['stream'] for dep, info in mbs_xmd["buildrequires"].items()}
         property_json = json.dumps(OrderedDict(sorted(mmd_formatted_buildrequires.items())))
-        context = hashlib.sha1(property_json).hexdigest()
+        context = hashlib.sha1(property_json, usedforsecurity=False).hexdigest()
 
         # Update the database now
         connection.execute(
