@@ -406,7 +406,8 @@ class DBResolver(GenericResolver):
             for sibling_id in build.siblings(self.db_session):
                 sibling_build = models.ModuleBuild.get_by_id(self.db_session, sibling_id)
                 if sibling_build.state not in (
-                        models.BUILD_STATES["ready"], models.BUILD_STATES["failed"]
+                        models.BUILD_STATES["ready"], models.BUILD_STATES["failed"],
+                        models.BUILD_STATES["garbage"]
                 ):
                     raise UnprocessableEntity('Buildrequire {}-{}-{} is in "{}" state'.format(
                         sibling_build.name, sibling_build.stream, sibling_build.version,
