@@ -6,6 +6,7 @@ to use.
 """
 
 from __future__ import absolute_import
+from contextlib import contextmanager
 import itertools
 
 try:
@@ -28,7 +29,7 @@ import module_build_service.common.monitor as monitor
 
 from module_build_service.scheduler import events
 from module_build_service.scheduler.db_session import db_session
-from module_build_service.scheduler.handlers import components, repos, modules, greenwave, tags
+from module_build_service.scheduler.handlers import components, repos, modules, tags
 
 
 def no_op_handler(*args, **kwargs):
@@ -57,7 +58,6 @@ ON_MODULE_CHANGE_HANDLERS = {
 # Only one kind of repo change event, though...
 ON_REPO_CHANGE_HANDLER = repos.done
 ON_TAG_CHANGE_HANDLER = tags.tagged
-ON_DECISION_UPDATE_HANDLER = greenwave.decision_update
 
 
 class MBSConsumer(fedmsg.consumers.FedmsgConsumer):
@@ -234,12 +234,6 @@ class MBSConsumer(fedmsg.consumers.FedmsgConsumer):
                 models.ModuleBuild.get_by_id(db_session, event_info["module_build_id"])
             )
 
-        if event == events.GREENWAVE_DECISION_UPDATE:
-            return (
-                ON_DECISION_UPDATE_HANDLER,
-                greenwave.get_corresponding_module_build(event_info["subject_identifier"])
-            )
-
         return None, None
 
     def process_message(self, event_info):
@@ -261,39 +255,49 @@ class MBSConsumer(fedmsg.consumers.FedmsgConsumer):
             log.debug("No module associated with msg %s", event_info["msg_id"])
             return
 
-        MBSConsumer.current_module_build_id = build.id
+        with set_current_module_build_id(build.id):
+            log.info("Calling %s", idx)
 
-        log.info("Calling %s", idx)
+            kwargs = event_info.copy()
+            kwargs.pop("event")
 
-        kwargs = event_info.copy()
-        kwargs.pop("event")
+            try:
+                if conf.celery_broker_url:
+                    # handlers are also Celery tasks, when celery_broker_url is configured,
+                    # call "delay" method to run the handlers as Celery async tasks
+                    func = getattr(handler, "delay")
+                    func(**kwargs)
+                else:
+                    handler(**kwargs)
+            except Exception as e:
+                log.exception("Could not process message handler.")
+                db_session.rollback()
+                db_session.refresh(build)
+                build.transition(
+                    db_session,
+                    conf,
+                    state=models.BUILD_STATES["failed"],
+                    state_reason=str(e),
+                    failure_type="infra",
+                )
+                db_session.commit()
 
-        try:
-            if conf.celery_broker_url:
-                # handlers are also Celery tasks, when celery_broker_url is configured,
-                # call "delay" method to run the handlers as Celery async tasks
-                func = getattr(handler, "delay")
-                func(**kwargs)
-            else:
-                handler(**kwargs)
-        except Exception as e:
-            log.exception("Could not process message handler.")
-            db_session.rollback()
-            db_session.refresh(build)
-            build.transition(
-                db_session,
-                conf,
-                state=models.BUILD_STATES["failed"],
-                state_reason=str(e),
-                failure_type="infra",
-            )
-            db_session.commit()
+                # Allow caller to do something when error is occurred.
+                raise
+            finally:
+                log.debug("Done with %s", idx)
 
-            # Allow caller to do something when error is occurred.
-            raise
-        finally:
-            MBSConsumer.current_module_build_id = None
-            log.debug("Done with %s", idx)
+
+@contextmanager
+def set_current_module_build_id(build_id):
+    """Context manager to temporarily set the module build ID - this is
+    needed to get logging to go to the right build log.
+    """
+    MBSConsumer.current_module_build_id = build_id
+    try:
+        yield
+    finally:
+        MBSConsumer.current_module_build_id = None
 
 
 def get_global_consumer():
