@@ -4,7 +4,7 @@ from __future__ import absolute_import
 
 import sqlalchemy.event
 from sqlalchemy.pool import NullPool
-from sqlalchemy.orm import scoped_session, sessionmaker
+from sqlalchemy.orm import scoped_session, sessionmaker, Session
 
 from module_build_service.common.config import conf
 from module_build_service.common.models import (
@@ -24,8 +24,8 @@ def _setup_event_listeners(db_session):
     )
 
     for event, handler in event_hooks:
-        if not sqlalchemy.event.contains(db_session, event, handler):
-            sqlalchemy.event.listen(db_session, event, handler)
+        if not sqlalchemy.event.contains(Session, event, handler):
+            sqlalchemy.event.listen(Session, event, handler)
 
     # initialize DB event listeners from the monitor module
     from module_build_service.common.monitor import db_hook_event_listeners
@@ -39,14 +39,6 @@ def apply_engine_options(conf):
     }
     if conf.sqlalchemy_database_uri.startswith("sqlite://"):
         options.update({
-            # For local module build, MBS is actually a multi-threaded
-            # application. The command submitting a module build runs in its
-            # own thread, and the backend build workflow, implemented as a
-            # fedmsg consumer on top of fedmsg-hub, runs in separate threads.
-            # So, disable this option in order to allow accessing data which
-            # was written from another thread.
-            "connect_args": {"check_same_thread": False},
-
             # Both local module build and running tests requires a file-based
             # SQLite database, we do not use a connection pool for these two
             # scenarios.
@@ -68,6 +60,7 @@ def apply_engine_options(conf):
         apply_mbs_option("sqlalchemy_pool_timeout", "pool_timeout")
         apply_mbs_option("sqlalchemy_pool_recycle", "pool_recycle")
         apply_mbs_option("sqlalchemy_max_overflow", "max_overflow")
+        apply_mbs_option("sqlalchemy_connect_args", "connect_args")
 
         options.update(pool_options)
 
