@@ -3,7 +3,6 @@
 """ Handlers for module change events on the message bus. """
 
 from __future__ import absolute_import
-from datetime import datetime
 import logging
 import os
 
@@ -29,7 +28,6 @@ from module_build_service.scheduler import celery_app, events
 from module_build_service.scheduler.db_session import db_session
 from module_build_service.scheduler.default_modules import (
     add_default_modules, handle_collisions_with_base_module_rpms)
-from module_build_service.scheduler.greenwave import greenwave
 from module_build_service.scheduler.reuse import attempt_to_reuse_all_components
 from module_build_service.scheduler.submit import format_mmd, get_module_srpm_overrides
 from module_build_service.scheduler.ursine import handle_stream_collision_modules
@@ -61,8 +59,17 @@ def failed(msg_id, module_build_id, module_build_state):
             "Note that retrieved module state %r doesn't match message module state %r",
             build.state, module_build_state,
         )
-        # This is ok.. it's a race condition we can ignore.
-        pass
+
+    if conf.strict_module_state_transitions:
+        valid_states = (
+            models.BUILD_STATES["init"],
+            models.BUILD_STATES["wait"],
+            models.BUILD_STATES["build"],
+            models.BUILD_STATES["failed"],
+        )
+        if build.state not in valid_states:
+            log.error("Module failed handler called while module in state %r", build.state)
+            return
 
     if build.koji_tag:
         builder = GenericBuilder.create_from_module(db_session, build, conf)
@@ -123,18 +130,19 @@ def done(msg_id, module_build_id, module_build_state):
             "Note that retrieved module state %r doesn't match message module state %r",
             build.state, module_build_state,
         )
-        # This is ok.. it's a race condition we can ignore.
-        pass
+
+    if conf.strict_module_state_transitions:
+        valid_states = (
+            models.BUILD_STATES["build"],
+            models.BUILD_STATES["done"],
+        )
+        if build.state not in valid_states:
+            log.error("Module done handler called while module in state %r", build.state)
+            return
 
     # Scratch builds stay in 'done' state
     if not build.scratch:
-        if greenwave is None or greenwave.check_gating(build):
-            build.transition(db_session, conf, state=models.BUILD_STATES["ready"])
-        else:
-            build.state_reason = "Gating failed"
-            if greenwave.error_occurred:
-                build.state_reason += " (Error occured while querying Greenwave)"
-            build.time_modified = datetime.utcnow()
+        build.transition(db_session, conf, state=models.BUILD_STATES["ready"])
         db_session.commit()
 
     build_logs.stop(build)
@@ -199,15 +207,8 @@ def init(msg_id, module_build_id, module_build_state):
         # Sets xmd["mbs"]["ursine_rpms"] with RPMs from the buildrequired base modules which
         # conflict with the RPMs from other buildrequired modules. This is done to prefer modular
         # RPMs over base module RPMs even if their NVR is lower.
-        if conf.system in ("koji", "test"):
-            handle_collisions_with_base_module_rpms(mmd, arches)
-        else:
-            log.warning(
-                "The necessary conflicts could not be generated due to RHBZ#1693683. "
-                "Some RPMs from the base modules (%s) may end up being used over modular RPMs. "
-                "This may result in different behavior than a production build.",
-                ", ".join(conf.base_module_names)
-            )
+        handle_collisions_with_base_module_rpms(mmd, arches,
+                                                force_for_old_dnf=conf.system in ("koji", "test"))
 
         mmd = record_filtered_rpms(mmd)
         build.modulemd = mmd_to_str(mmd)
@@ -250,8 +251,8 @@ def generate_module_build_koji_tag(build):
     :return: generated koji tag.
     :rtype: str
     """
-    log.info("Getting tag for %s:%s:%s", build.name, build.stream, build.version)
     if conf.system in ["koji", "test"]:
+        log.info("Getting tag for %s:%s:%s", build.name, build.stream, build.version)
         return KojiModuleBuilder.generate_koji_tag(
             build.name,
             build.stream,
@@ -349,8 +350,15 @@ def wait(msg_id, module_build_id, module_build_state):
             "Note that retrieved module state %r doesn't match message module state %r",
             build.state, module_build_state,
         )
-        # This is ok.. it's a race condition we can ignore.
-        pass
+
+    if conf.strict_module_state_transitions:
+        valid_states = (
+            models.BUILD_STATES["init"],
+            models.BUILD_STATES["wait"],
+        )
+        if build.state not in valid_states:
+            log.error("Module wait handler called while module in state %r", build.state)
+            return
 
     try:
         build_deps = get_module_build_dependencies(build)
@@ -392,7 +400,17 @@ def wait(msg_id, module_build_id, module_build_state):
         "Adding dependencies %s into buildroot for module %s:%s:%s",
         build_deps.keys(), build.name, build.stream, build.version,
     )
-    builder.buildroot_add_repos(build_deps)
+    try:
+        builder.buildroot_add_repos(build_deps)
+    except SystemError as e:
+        reason = "Failed to add dependencies to buildroot: %s" % e
+        log.exception(reason)
+        build.transition(
+            db_session, conf,
+            state=models.BUILD_STATES["failed"],
+            state_reason=reason, failure_type="infra")
+        db_session.commit()
+        raise
 
     if not build.component_builds:
         log.info("There are no components in module %r, skipping build" % build)
