@@ -247,7 +247,7 @@ def _scm_get_latest(data):
     return {"pkg_name": data.rpm_component.get_name(), "pkg_ref": pkgref, "error": None}
 
 
-def format_mmd(mmd, scmurl, module=None, db_session=None, srpm_overrides=None):
+def format_mmd(mmd, scmurl, module=None, db_session=None, srpm_overrides=None, default_ref=None):
     """
     Prepares the modulemd for the MBS. This does things such as replacing the
     branches of components with commit hashes and adding metadata in the xmd
@@ -281,6 +281,9 @@ def format_mmd(mmd, scmurl, module=None, db_session=None, srpm_overrides=None):
 
         xmd["mbs"]["commit"] = full_scm_hash
 
+    if default_ref is None:
+        default_ref = xmd["mbs"].get("branch") or conf.default_branch
+
     if mmd.get_rpm_component_names() or mmd.get_module_component_names():
         if "rpms" not in xmd["mbs"]:
             xmd["mbs"]["rpms"] = {}
@@ -309,7 +312,7 @@ def format_mmd(mmd, scmurl, module=None, db_session=None, srpm_overrides=None):
             if not pkg.get_cache():
                 pkg.set_cache(conf.rpms_default_cache + pkgname)
             if not pkg.get_ref():
-                pkg.set_ref(conf.default_branch)
+                pkg.set_ref(default_ref)
             if not pkg.get_arches():
                 for arch in conf.arches:
                     pkg.add_restricted_arch(arch)
@@ -325,7 +328,7 @@ def format_mmd(mmd, scmurl, module=None, db_session=None, srpm_overrides=None):
             if not mod.get_repository():
                 mod.set_repository(conf.modules_default_repository + modname)
             if not mod.get_ref():
-                mod.set_ref(conf.default_branch)
+                mod.set_ref(default_ref)
 
         # It is possible to override the ref of RPM component using
         # the rpm_component_ref_overrides.
@@ -508,6 +511,8 @@ def record_component_builds(
     # planned for batch 2 and following.
     batch = initial_batch
 
+    default_ref = mmd.get_xmd()["mbs"].get("branch")
+
     for component in all_components:
         # Increment the batch number when buildorder increases.
         if previous_buildorder != component.get_buildorder():
@@ -523,7 +528,7 @@ def record_component_builds(
             # It is OK to whitelist all URLs here, because the validity
             # of every URL have been already checked in format_mmd(...).
             included_mmd = fetch_mmd(full_url, whitelist_url=True)[0]
-            format_mmd(included_mmd, module.scmurl, module, db_session, srpm_overrides)
+            format_mmd(included_mmd, module.scmurl, module, db_session, srpm_overrides, default_ref)
             batch = record_component_builds(
                 included_mmd, module, batch, previous_buildorder, main_mmd)
             continue
