@@ -187,9 +187,13 @@ def get_mmds_required_by_module_recursively(
     base_module_mmds = get_base_module_mmds(db_session, mmd)
     if not base_module_mmds["ready"]:
         base_module_choices = " or ".join(conf.base_module_names)
+        missing = base_module_mmds["missing"]
+        missing_msg = ""
+        if missing:
+            missing_msg = "  Missing streams are ({}).".format(", ".join(missing))
         raise UnprocessableEntity(
-            "None of the base module ({}) streams in the buildrequires section could be found"
-            .format(base_module_choices)
+            "None of the base module ({}) streams in the buildrequires section could be found.{}"
+            .format(base_module_choices, missing_msg)
         )
 
     # Add base modules to `mmds`.
@@ -497,8 +501,7 @@ def _validate_stream_name_for_static_context(module, stream, context, dep_type):
     if stream_type is not str:
         raise ValidationError(("The module '{module}' in '{dep_type}' of the '{context}' "
                                "static context is of type '{stream_type}' should be "
-                               "'str' type.").format(stream=stream,
-                                                     module=module,
+                               "'str' type.").format(module=module,
                                                      dep_type=dep_type,
                                                      context=context,
                                                      stream_type=stream_type))
