@@ -270,37 +270,24 @@ def _apply_dep_overrides(mmd, params):
             )
 
 
-def _apply_rpm_component_ref_overrides(mmd, params):
+def _apply_xmd_params(mmd, params):
     """
-    If `rpm_component_ref_overrides` is given, note it in the xmd.
+    Note some parameters in the mbs section of the xmd.
 
     :param Modulemd.ModuleStream mmd: the modulemd to apply the overrides on
     :param dict params: the API parameters passed in by the user
     """
-    ref_overrides = params.get("rpm_component_ref_overrides", {})
-    if not ref_overrides:
-        # No changes needed.
+    xmd_updates = {}
+
+    for param in ("rpm_component_ref_overrides", "side_tag", "branch"):
+        value = params.get(param)
+        if value:
+            xmd_updates[param] = value
+
+    if not xmd_updates:
         return
-
     xmd = mmd.get_xmd()
-    xmd.setdefault("mbs", {})["rpm_component_ref_overrides"] = ref_overrides
-    mmd.set_xmd(xmd)
-
-
-def _apply_side_tag(mmd, params):
-    """
-    If a side tag identifier is given, note it in the xmd
-
-    :param Modulemd.ModuleStream mmd: the modulemd to apply the overrides on
-    :param dict params: the API parameters passed in by the user
-    """
-    side_tag = params.get('side_tag')
-    if not side_tag:
-        # no changes needed
-        return
-
-    xmd = mmd.get_xmd()
-    xmd.setdefault("mbs", {})["side_tag"] = side_tag
+    xmd.setdefault("mbs", {}).update(xmd_updates)
     mmd.set_xmd(xmd)
 
 
@@ -617,8 +604,7 @@ def submit_module_build(db_session, username, stream_or_packager, params, module
     for mmd in input_mmds:
         validate_mmd(mmd)
         _apply_dep_overrides(mmd, params)
-        _apply_side_tag(mmd, params)
-        _apply_rpm_component_ref_overrides(mmd, params)
+        _apply_xmd_params(mmd, params)
         _modify_buildtime_streams(db_session, mmd, resolve_base_module_virtual_streams)
         _process_support_streams(db_session, mmd, params)
         mmds += generate_expanded_mmds(db_session, mmd, raise_if_stream_ambigous,
