@@ -369,6 +369,7 @@ class BaseHandler(object):
     valid_params = {
         "branch",
         "buildrequire_overrides",
+        "rpm_component_ref_overrides",
         "modulemd",
         "module_name",
         "module_stream",
@@ -378,6 +379,7 @@ class BaseHandler(object):
         "require_overrides",
         "scmurl",
         "scratch",
+        "side_tag",
         "srpms",
     }
 
@@ -424,11 +426,30 @@ class BaseHandler(object):
                 if not isinstance(stream, string_types):
                     raise ValidationError(invalid_override_msg)
 
+    def _validate_ref_overrides_format(self, key):
+        """
+        Validate any dependency overrides provided to the API.
+
+        :param str key: the override key to validate
+        :raises ValidationError: when the overrides are an invalid format
+        """
+        if not self.data.get(key):
+            return
+        invalid_override_msg = (
+            'The "{}" parameter must be an object with the keys as component '
+            "names and the values as strings of refs".format(key)
+        )
+        if not isinstance(self.data[key], dict):
+            raise ValidationError(invalid_override_msg)
+        for ref in self.data[key].values():
+            if not isinstance(ref, string_types):
+                raise ValidationError(invalid_override_msg)
+
     def validate_optional_params(self):
         forbidden_params = [k for k in self.data if k not in self.valid_params]
         if forbidden_params:
             raise ValidationError(
-                "The request contains unspecified parameters: {}".format(
+                "The request contains invalid parameters: {}".format(
                     ", ".join(forbidden_params))
             )
 
@@ -451,6 +472,7 @@ class BaseHandler(object):
 
         self._validate_dep_overrides_format("buildrequire_overrides")
         self._validate_dep_overrides_format("require_overrides")
+        self._validate_ref_overrides_format("rpm_component_ref_overrides")
 
         if "reuse_components_from" in self.data:
             if "rebuild_strategy" in self.data and self.data["rebuild_strategy"] == "all":
@@ -500,8 +522,9 @@ class SCMHandler(BaseHandler):
             raise Forbidden("The submitted scmurl %s is not allowed" % url)
 
         if not get_scm_url_re().match(url):
-            log.error("The submitted scmurl %r is not valid" % url)
-            raise ValidationError("The submitted scmurl %s is not valid" % url)
+            msg = "Expected format is '%s?[module-path]#[revision]'" % url
+            log.error("The submitted scmurl %r is not valid.  %s" % (url, msg))
+            raise ValidationError("The submitted scmurl %s is not valid.  %s" % (url, msg))
 
         if not skip_branch and "branch" not in self.data:
             log.error("Missing branch")
