@@ -281,6 +281,17 @@ def provide_test_client(request):
 
 
 @pytest.fixture(autouse=True, scope="session")
-def create_database(request):
+def create_database(request, tmpdir_factory):
     """Drop and recreate all tables"""
-    clean_database(add_platform_module=False, add_default_arches=False)
+
+    # pysqlite + the SQLite memory backend doesn't handle multiple threads usefully:
+    # either each thread gets its own backend, or the threads stomp on each others
+    # transaction state. So, before running tests, replace the memory backend with
+    # a file backend - if this ends up on tmpfs, its almost as fast as the memory
+    # backend.
+    database_uri = None
+    if module_build_service.app.config["SQLALCHEMY_DATABASE_URI"] == 'sqlite:///:memory:':
+        database_path = str(tmpdir_factory.getbasetemp() / "test.db")
+        database_uri = 'sqlite:///' + database_path
+
+    clean_database(database_uri=database_uri, add_platform_module=False, add_default_arches=False)
