@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: MIT
 from __future__ import absolute_import
 import os
+import logging
 
 from datetime import datetime
 from mock import patch, PropertyMock
@@ -10,7 +11,7 @@ import pytest
 from module_build_service.builder.MockModuleBuilder import load_local_builds
 from module_build_service.common import models
 from module_build_service.common.config import conf
-from module_build_service.common.errors import UnprocessableEntity
+from module_build_service.common.errors import StreamNotXyz, UnprocessableEntity
 from module_build_service.common.models import ModuleBuild
 from module_build_service.common.modulemd import Modulemd
 from module_build_service.common.utils import import_mmd, load_mmd, mmd_to_str
@@ -19,6 +20,9 @@ from module_build_service.scheduler.db_session import db_session
 import tests
 
 
+LOGGER = logging.getLogger(__name__)
+
+
 class TestDBModule:
 
     def test_get_buildrequired_modulemds(self):
@@ -76,6 +80,37 @@ class TestDBModule:
                 "platform:f29.2.0:3:00000000"
             }
 
+    @pytest.mark.parametrize("provide_test_data",
+                             [{"multiple_stream_versions": True}], indirect=True)
+    def test_get_compatible_base_module_modulemds_no_virtual(self, provide_test_data):
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
+
+        platform = db_session.query(ModuleBuild).filter_by(name="platform", stream="f29.1.0").one()
+        platform_mmd = platform.mmd()
+
+        with pytest.raises(RuntimeError, match=r"Virtual stream list must not be empty"):
+            resolver.get_compatible_base_module_modulemds(
+                platform_mmd, stream_version_lte=True, virtual_streams=[],
+                states=[models.BUILD_STATES["ready"]]
+            )
+
+    def test_get_compatible_base_module_modulemds_stream_not_xyz(
+            self, require_platform_and_default_arch, caplog
+    ):
+        resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
+
+        platform = db_session.query(ModuleBuild).filter_by(name="platform", stream="f28").one()
+        platform_mmd = platform.mmd()
+
+        with pytest.raises(
+                StreamNotXyz,
+                match=(r"Cannot get compatible base modules, because stream "
+                       r"of resolved base module platform:f28 is not in x\.y\.z format")
+        ):
+            resolver.get_compatible_base_module_modulemds(
+                platform_mmd, stream_version_lte=True, virtual_streams=["f29"],
+                states=[models.BUILD_STATES["ready"]])
+
     @pytest.mark.parametrize("empty_buildrequires", [False, True])
     def test_get_module_build_dependencies(self, empty_buildrequires, reuse_component_init_data):
         """
@@ -101,7 +136,7 @@ class TestDBModule:
 
     @pytest.mark.parametrize("missing_format", [False, True])
     def test_get_module_build_dependencies_side_tag(
-            self, missing_format, reuse_component_init_data):
+            self, missing_format, reuse_component_init_data, caplog):
         """
         Test that we get the correct base module tag when a side tag is specified
         """
@@ -123,8 +158,19 @@ class TestDBModule:
             db_session.commit()
             expected = {"module-f28-build"}
         resolver = mbs_resolver.GenericResolver.create(db_session, conf, backend="db")
-        result = resolver.get_module_build_dependencies(mmd=mmd).keys()
-        assert set(result) == expected
+        if missing_format:
+            with pytest.raises(RuntimeError) as excinfo:
+                result = resolver.get_module_build_dependencies(mmd=mmd).keys()
+                assert set(result) == expected
+            msg = "None of the buildrequired base modules are configured for side tags"
+            assert msg in str(excinfo.value)
+            assert (
+                'Side tag requested, but base module platform lacks koji_side_tag_format value' in
+                caplog.text
+            )
+        else:
+            result = resolver.get_module_build_dependencies(mmd=mmd).keys()
+            assert set(result) == expected
 
     def test_get_module_build_dependencies_recursive(self, reuse_component_init_data):
         """
