@@ -2,11 +2,14 @@
 # SPDX-License-Identifier: MIT
 from __future__ import absolute_import
 
+from datetime import timedelta
+
 import mock
 import pytest
 from sqlalchemy.orm.session import make_transient
 
 from module_build_service.common import models
+from module_build_service.common.errors import StreamNotXyz
 from module_build_service.common.modulemd import Modulemd
 from module_build_service.common.utils import import_mmd, load_mmd, mmd_to_str
 from module_build_service.scheduler.db_session import db_session
@@ -293,80 +296,129 @@ class TestUtilsModuleReuse:
         assert reusable_module.id == build_module.reused_module_id
         assert reusable_module.id == reused_module.id
 
-    @pytest.mark.parametrize("allow_ocbm", (True, False))
+    _EXCEPTION = object()
+
+    @pytest.mark.parametrize("allow_ocbm,build_req,available_req,expected", [
+        # When allow_only_compatible_base_modules is false, only modules
+        # built against the exact same base module stream can be used
+        (False, "f29.2.0", ("f29.2.0",), "f29.2.0"),
+        (False, "f29.2.0", ("f29.0.0",), None),
+        # When it is true, any base module x.y2.z2 where y2.z2 <= y1.z1
+        # is a candidate
+        (True, "f29.2.0", ("f29.2.0", "f29.0.0", "f29.3.0"), "f29.2.0"),
+        (True, "f29.2.0", ("f29.1.0", "f29.0.0", "f29.3.0"), "f29.1.0"),
+        # But if the major is different, they don't (the code below adds "f28.0.0"
+        # with the "f29" virtual stream, so it would be a candidate otherwise)
+        (True, "f29.2.0", ("f28.0.0",), None),
+        # the virtual stream must also match (+ is used to skip virtual stream addition)
+        (True, "f29.2.0", ("+f29.1.0",), None),
+        # If the buildrequired base module isn't in x.y.z form, we raise an
+        # exception
+        (True, "f29", ("f29",), _EXCEPTION),
+        (True, "f29", ("f29.0.0",), _EXCEPTION),
+    ])
     @mock.patch(
         "module_build_service.common.config.Config.allow_only_compatible_base_modules",
         new_callable=mock.PropertyMock,
     )
-    def test_get_reusable_module_use_latest_build(self, cfg, allow_ocbm):
+    def test_get_reusable_module_use_latest_build(
+            self, cfg, allow_ocbm, build_req, available_req, expected):
         """
         Test that the `get_reusable_module` tries to reuse the latest module in case when
         multiple modules can be reused allow_only_compatible_base_modules is True.
         """
         cfg.return_value = allow_ocbm
-        # Set "fedora" virtual stream to platform:f28.
-        platform_f28 = db_session.query(models.ModuleBuild).filter_by(name="platform").one()
-        mmd = platform_f28.mmd()
-        xmd = mmd.get_xmd()
-        xmd["mbs"]["virtual_streams"] = ["fedora"]
-        mmd.set_xmd(xmd)
-        platform_f28.modulemd = mmd_to_str(mmd)
-        platform_f28.update_virtual_streams(db_session, ["fedora"])
 
-        # Create platform:f29 with "fedora" virtual stream.
-        mmd = load_mmd(read_staged_data("platform"))
-        mmd = mmd.copy("platform", "f29")
-        xmd = mmd.get_xmd()
-        xmd["mbs"]["virtual_streams"] = ["fedora"]
-        mmd.set_xmd(xmd)
-        platform_f29 = import_mmd(db_session, mmd)[0]
+        # Create all the platform streams we need
+        needed_platform_streams = set([build_req])
+        needed_platform_streams.update(available_req)
+        platform_modules = {}
+        for stream in needed_platform_streams:
+            skip_virtual = False
+            if stream.startswith('+'):
+                skip_virtual = True
+                stream = stream[1:]
 
-        # Create another copy of `testmodule:master` which should be reused, because its
-        # stream version will be higher than the previous one. Also set its buildrequires
-        # to platform:f29.
-        latest_module = db_session.query(models.ModuleBuild).filter_by(
-            name="testmodule", state=models.BUILD_STATES["ready"]).one()
-        # This is used to clone the ModuleBuild SQLAlchemy object without recreating it from
-        # scratch.
-        db_session.expunge(latest_module)
-        make_transient(latest_module)
+            # Create platform:f29.0.0 with "f29" virtual stream.
+            mmd = load_mmd(read_staged_data("platform"))
+            mmd = mmd.copy("platform", stream)
+            xmd = mmd.get_xmd()
+            xmd["mbs"]["virtual_streams"] = [] if skip_virtual else ["f29"]
+            mmd.set_xmd(xmd)
+            platform_modules[stream] = import_mmd(db_session, mmd)[0]
 
-        # Change the platform:f28 buildrequirement to platform:f29 and recompute the build_context.
-        mmd = latest_module.mmd()
-        xmd = mmd.get_xmd()
-        xmd["mbs"]["buildrequires"]["platform"]["stream"] = "f29"
-        mmd.set_xmd(xmd)
-        latest_module.modulemd = mmd_to_str(mmd)
-        contexts = models.ModuleBuild.contexts_from_mmd(
-            latest_module.modulemd
-        )
-        latest_module.build_context = contexts.build_context
-        latest_module.context = contexts.context
-        latest_module.buildrequires = [platform_f29]
+        # Modify a module to buildrequire a particular platform stream
+        def modify_buildrequires(module, platform_module):
+            mmd = module.mmd()
+            deps = mmd.get_dependencies()[0]
+            deps.clear_buildtime_dependencies()
+            deps.add_buildtime_stream('platform', platform_module.stream)
+            xmd = mmd.get_xmd()
+            xmd["mbs"]["buildrequires"]["platform"]["stream"] = platform_module.stream
+            mmd.set_xmd(xmd)
+            module.modulemd = mmd_to_str(mmd)
+            contexts = models.ModuleBuild.contexts_from_mmd(
+                module.modulemd
+            )
+            module.build_context = contexts.build_context
+            module.context = contexts.context
+            module.buildrequires = [platform_module]
 
-        # Set the `id` to None, so new one is generated by SQLAlchemy.
-        latest_module.id = None
-        db_session.add(latest_module)
-        db_session.commit()
+        stream_to_testmodule_id = {}
+
+        first = True
+        for stream in available_req:
+            if stream.startswith('+'):
+                stream = stream[1:]
+
+            if first:
+                # Reuse the testmodule:master already in the database
+                module = db_session.query(models.ModuleBuild).filter_by(
+                    name="testmodule", state=models.BUILD_STATES["ready"]).one()
+
+                modify_buildrequires(module, platform_modules[stream])
+                time_completed = module.time_completed
+
+                first = False
+            else:
+                # Create another copy of `testmodule:master`, and modify it
+                module = db_session.query(models.ModuleBuild).filter_by(
+                    name="testmodule", state=models.BUILD_STATES["ready"]).first()
+
+                # This is used to clone the ModuleBuild SQLAlchemy object without recreating it from
+                # scratch.
+                db_session.expunge(module)
+                make_transient(module)
+
+                modify_buildrequires(module, platform_modules[stream])
+
+                # Add modules with ascending time_completed
+                time_completed += timedelta(days=1)
+                module.time_completed = time_completed
+
+                # Set the `id` to None, so new one is generated by SQLAlchemy.
+                module.id = None
+                db_session.add(module)
+
+            db_session.commit()
+            stream_to_testmodule_id[stream] = module.id
 
         module = db_session.query(models.ModuleBuild)\
                            .filter_by(name="testmodule")\
                            .filter_by(state=models.BUILD_STATES["build"])\
                            .one()
+        modify_buildrequires(module, platform_modules[build_req])
         db_session.commit()
 
-        reusable_module = get_reusable_module(module)
-
-        if allow_ocbm:
-            assert reusable_module.id == latest_module.id
+        if expected is TestUtilsModuleReuse._EXCEPTION:
+            with pytest.raises(StreamNotXyz):
+                get_reusable_module(module)
         else:
-            # There are two testmodules in ready state, the first one with
-            # lower id is what we want.
-            first_module = db_session.query(models.ModuleBuild).filter_by(
-                name="testmodule", state=models.BUILD_STATES["ready"]
-            ).order_by(models.ModuleBuild.id).first()
-
-            assert reusable_module.id == first_module.id
+            reusable_module = get_reusable_module(module)
+            if expected:
+                assert reusable_module.id == stream_to_testmodule_id[expected]
+            else:
+                assert reusable_module is None
 
     @pytest.mark.parametrize("allow_ocbm", (True, False))
     @mock.patch(
