@@ -123,14 +123,22 @@ class TestSubmit:
             None,
         ],
     )
+    @pytest.mark.parametrize(
+        "rpm_component_ref_overrides",
+        [
+            {"tangerine": "ref_override"},
+            None,
+        ],
+    )
     @mock.patch("module_build_service.common.scm.SCM")
-    def test_format_mmd(self, mocked_scm, srpm_overrides, scmurl):
+    def test_format_mmd(self, mocked_scm, srpm_overrides, rpm_component_ref_overrides, scmurl):
         mocked_scm.return_value.commit = "620ec77321b2ea7b0d67d82992dda3e1d67055b4"
         # For all the RPMs in testmodule, get_latest is called
         hashes_returned = {
             "master": "fbed359411a1baa08d4a88e0d12d426fbf8f602c",
             "f28": "4ceea43add2366d8b8c5a622a2fb563b625b9abf",
             "f27": "5deef23acd2367d8b8d5a621a2fc568b695bc3bd",
+            "ref_override": "ref_override",
         }
 
         def mocked_get_latest(ref="master"):
@@ -146,6 +154,13 @@ class TestSubmit:
         if srpm_overrides:
             # Set a bogus ref that will raise an exception if not properly ignored.
             mmd.get_rpm_component("perl-List-Compare").set_ref("bogus")
+        if rpm_component_ref_overrides:
+            xmd = mmd.get_xmd()
+            xmd["mbs"] = {"rpm_component_ref_overrides": rpm_component_ref_overrides}
+            mmd.set_xmd(xmd)
+            tangerine_ref = rpm_component_ref_overrides["tangerine"]
+        else:
+            tangerine_ref = hashes_returned["f27"]
         format_mmd(mmd, scmurl, srpm_overrides=srpm_overrides)
 
         # Make sure that original refs are not changed.
@@ -167,7 +182,7 @@ class TestSubmit:
                 "rpms": {
                     "perl-List-Compare": {"ref": "fbed359411a1baa08d4a88e0d12d426fbf8f602c"},
                     "perl-Tangerine": {"ref": "4ceea43add2366d8b8c5a622a2fb563b625b9abf"},
-                    "tangerine": {"ref": "5deef23acd2367d8b8d5a621a2fc568b695bc3bd"},
+                    "tangerine": {"ref": tangerine_ref},
                 },
                 "scmurl": "",
             }
@@ -177,6 +192,8 @@ class TestSubmit:
             xmd["mbs"]["scmurl"] = scmurl
         if srpm_overrides:
             xmd["mbs"]["rpms"]["perl-List-Compare"]["ref"] = match_anything
+        if rpm_component_ref_overrides:
+            xmd["mbs"]["rpm_component_ref_overrides"] = match_anything
         mmd_xmd = mmd.get_xmd()
         assert mmd_xmd == xmd
 
