@@ -17,7 +17,7 @@ from module_build_service.common.utils import (mmd_to_str, load_mmd,
 from module_build_service.scheduler.db_session import db_session
 from module_build_service.web.submit import (
     get_prefixed_version, submit_module_build, submit_module_build_from_yaml,
-    process_module_context_configuration, _apply_side_tag,
+    process_module_context_configuration, _apply_xmd_params,
 )
 from tests import (
     scheduler_init_data,
@@ -317,28 +317,34 @@ data:
         """
         return load_mmd(yaml_str)
 
-    def test_apply_side_tag(self):
+    def test_apply_xmd_params(self):
         """
-        Test that the side tag option is correctly added into the xmd
+        Test that key params are correctly added into the xmd
         """
         mmd = self.get_mmd()
-        side_tag = "SIDETAG"
-        _apply_side_tag(mmd, {"side_tag": side_tag})
+        params = {
+            "side_tag": "SIDETAG",
+            "rpm_component_ref_overrides": {"pkg": "f4836ea0"},
+            "branch": "f37",
+        }
+        _apply_xmd_params(mmd, params)
 
         xmd = mmd.get_xmd()
-        assert xmd["mbs"]["side_tag"] == side_tag
+        for key in params:
+            assert xmd["mbs"][key] == params[key]
 
-    def test_apply_side_tag_no_option(self):
+    def test_apply_xmd_params_no_option(self):
         """
-        Test that the xmd is unchanged when option not given
+        Test that the xmd is unchanged when no relevant options are given
         """
         mmd = self.get_mmd()
         xmd_orig = mmd.get_xmd()
-        _apply_side_tag(mmd, {})
+        _apply_xmd_params(mmd, {})
 
         xmd = mmd.get_xmd()
         assert xmd == xmd_orig
-        assert "side_tag" not in xmd.get("mbs", {})
+        for key in ("side_tag", "rpm_component_ref_overrides", "branch"):
+            assert key not in xmd.get("mbs", {})
 
 
 @pytest.mark.usefixtures("reuse_component_init_data")
@@ -460,4 +466,7 @@ class TestUtilsComponentReuse:
         ):
             submit_module_build(db_session, "foo", mmd_copy, {"branch": "private-foo"}, version)
 
+        # re-copy because submit_module_build could modify xmd
+        mmd_copy = mmd.copy()
+        mmd_copy.set_xmd({})
         submit_module_build(db_session, "foo", mmd_copy, {"branch": "otherbranch"}, version)
